@@ -751,10 +751,10 @@ class QueryBuilder
         // Likewise, modes between and notBetween are only supported for numeric filters
         enum qBuilderFilter  { modeNormal = 0, modeLess = 1, modeGreater = 2, modeEndMatch = 3, modeBeginMatch = 4, modeBetween = 5, modeNotBetween = 6};
 
-        QueryBuilder();
+        LIBAMAROK_EXPORT QueryBuilder();
 
-        void addReturnValue( int table, TQ_INT64 value, bool caseSensitive = false /* unless value refers to a string */ );
-        void addReturnFunctionValue( int function, int table, TQ_INT64 value);
+        LIBAMAROK_EXPORT void addReturnValue( int table, TQ_INT64 value, bool caseSensitive = false /* unless value refers to a string */ );
+        LIBAMAROK_EXPORT void addReturnFunctionValue( int function, int table, TQ_INT64 value);
         uint countReturnValues();
 
         // Note: the filter chain begins in AND mode
@@ -774,7 +774,7 @@ class QueryBuilder
         void excludeFilter( int tables, TQ_INT64 value, const TQString& filter, int mode = modeNormal, bool exact = false );
 
         void addMatch( int tables, const TQString& match, bool interpretUnknown = true, bool caseSensitive = true );
-        void addMatch( int tables, TQ_INT64 value, const TQString& match, bool interpretUnknown = true, bool caseSensitive = true );
+        LIBAMAROK_EXPORT void addMatch( int tables, TQ_INT64 value, const TQString& match, bool interpretUnknown = true, bool caseSensitive = true );
         void addMatches( int tables, const TQStringList& match, bool interpretUnknown = true, bool caseSensitive = true );
         void excludeMatch( int tables, const TQString& match );
         void having( int table, TQ_INT64 value, int function, int mode, const TQString& match );
@@ -812,7 +812,7 @@ class QueryBuilder
         TQString query( bool withDeviceidPlaceholder = false ) { buildQuery( withDeviceidPlaceholder ); return m_query; };
         void clear();
 
-        TQStringList run();
+        LIBAMAROK_EXPORT TQStringList run();
 
         // Transform a string table.value "field" into enum values
         // @return true if we succeeded
