@@ -63,10 +63,6 @@ typedef TBool   BOOL;
 #else
 # ifndef _VXWORKS
 
-#  if defined(TQWS) && !defined(TQT_CLEAN_NAMESPACE)
-#error "You need to define TQT_CLEAN_NAMESPACE when using TQt with Helix. If you don't you'll have conflicts with the Helix INT32, UINT32, and UINT definitions"
-#  endif
-
    typedef char                    INT8;   /* signed 8 bit value */
    typedef unsigned char           UINT8;  /* unsigned 8 bit value */
    typedef short int               INT16;  /* signed 16 bit value */
