@@ -28,17 +28,17 @@
 #include "filebrowser.h"
 #include "k3bexporter.h"
 
-#include <kaction.h>
-#include <kapplication.h>
+#include <tdeaction.h>
+#include <tdeapplication.h>
 #include "kbookmarkhandler.h"
-#include <kdiroperator.h>
+#include <tdediroperator.h>
 #include <kiconloader.h>
-#include <kio/netaccess.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdeio/netaccess.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kpushbutton.h>     ///@see SearchPane
-#include <ktoolbarbutton.h>  ///@see ctor
+#include <tdetoolbarbutton.h>  ///@see ctor
 #include <kurlcombobox.h>
 #include <kurlcompletion.h>
 
@@ -68,7 +68,7 @@
 FileBrowser::FileBrowser( const char * name, Medium * medium )
         : TQVBox( 0, name )
 {
-    KActionCollection *actionCollection;
+    TDEActionCollection *actionCollection;
     SearchPane *searchPane;
 
     KURL *location;
@@ -79,7 +79,7 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
         m_medium = 0;
         location = new KURL( Amarok::config( "Filebrowser" )->readPathEntry( "Location", TQDir::homeDirPath() ) );
         KFileItem *currentFolder = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, *location );
-        //KIO sucks, NetAccess::exists puts up a dialog and has annoying error message boxes
+        //TDEIO sucks, NetAccess::exists puts up a dialog and has annoying error message boxes
         //if there is a problem so there is no point in using it anyways.
         //so... setting the diroperator to ~ is the least sucky option
         if ( !location->isLocalFile() || !currentFolder->isReadable() ) {
@@ -92,14 +92,14 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
         location = new KURL( m_medium->mountPoint() );
     }
 
-    KActionCollection* ac = new KActionCollection( this );
+    TDEActionCollection* ac = new TDEActionCollection( this );
     KStdAction::selectAll( TQT_TQOBJECT(this), TQT_SLOT( selectAll() ), ac, "filebrowser_select_all" );
 
-    KToolBar *toolbar = new Browser::ToolBar( this );
+    TDEToolBar *toolbar = new Browser::ToolBar( this );
 
     { //Filter LineEdit
-        KToolBar* searchToolBar = new Browser::ToolBar( this );
-        KToolBarButton *button = new KToolBarButton( "locationbar_erase", 0, searchToolBar );
+        TDEToolBar* searchToolBar = new Browser::ToolBar( this );
+        TDEToolBarButton *button = new TDEToolBarButton( "locationbar_erase", 0, searchToolBar );
         m_filter = new ClickLineEdit( i18n( "Enter search terms here" ), searchToolBar );
 
         searchToolBar->setStretchableWidget( m_filter );
@@ -164,7 +164,7 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
     }
 
     {
-        TQPopupMenu* const menu = static_cast<KActionMenu*>(actionCollection->action("popupMenu"))->popupMenu();
+        TQPopupMenu* const menu = static_cast<TDEActionMenu*>(actionCollection->action("popupMenu"))->popupMenu();
 
         menu->clear();
         menu->insertItem( SmallIconSet( Amarok::icon( "files" ) ), i18n( "&Load" ), MakePlaylist );
@@ -198,50 +198,50 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
     }
 
     {
-        KActionMenu *a;
+        TDEActionMenu *a;
 
-        a = static_cast<KActionMenu*>( actionCollection->action( "sorting menu" ) );
+        a = static_cast<TDEActionMenu*>( actionCollection->action( "sorting menu" ) );
         a->setIcon( Amarok::icon( "configure" ) );
         a->setDelayed( false ); //TODO should be done by KDirOperator
 
-        actionCollection->action( "delete" )->setShortcut( KShortcut( SHIFT + Key_Delete ) );
+        actionCollection->action( "delete" )->setShortcut( TDEShortcut( SHIFT + Key_Delete ) );
 
-        a = new KActionMenu( i18n("Bookmarks"), "bookmark", actionCollection, "bookmarks" );
+        a = new TDEActionMenu( i18n("Bookmarks"), "bookmark", actionCollection, "bookmarks" );
         a->setDelayed( false );
 
         new KBookmarkHandler( m_dir, a->popupMenu() );
     }
 
     {
-        if ( KAction *a = actionCollection->action( "up" ) )
+        if ( TDEAction *a = actionCollection->action( "up" ) )
             a->plug( toolbar );
-        if ( KAction *a = actionCollection->action( "back" ) )
+        if ( TDEAction *a = actionCollection->action( "back" ) )
             a->plug( toolbar );
-        if ( KAction *a = actionCollection->action( "forward" ) )
+        if ( TDEAction *a = actionCollection->action( "forward" ) )
             a->plug( toolbar );
-        if ( KAction *a = actionCollection->action( "home" ) )
+        if ( TDEAction *a = actionCollection->action( "home" ) )
             a->plug( toolbar );
-        if ( KAction *a = actionCollection->action( "reload" ) ) {
+        if ( TDEAction *a = actionCollection->action( "reload" ) ) {
             a->setIcon( Amarok::icon( "refresh" ) );
             a->plug( toolbar );
         }
 
         toolbar->insertLineSeparator();
 
-        if ( KAction *a = actionCollection->action( "short view" ) )
+        if ( TDEAction *a = actionCollection->action( "short view" ) )
             a->plug( toolbar );
-        if ( KAction *a = actionCollection->action( "detailed view" ) )
+        if ( TDEAction *a = actionCollection->action( "detailed view" ) )
             a->plug( toolbar );
 
         toolbar->insertLineSeparator();
 
-        if ( KAction *a = actionCollection->action( "sorting menu" ) )
+        if ( TDEAction *a = actionCollection->action( "sorting menu" ) )
             a->plug( toolbar );
-        if ( KAction *a = actionCollection->action( "bookmarks" ) )
+        if ( TDEAction *a = actionCollection->action( "bookmarks" ) )
             a->plug( toolbar );
 
 
-        KAction *gotoCurrent = new KAction( i18n("Go To Current Track Folder"), Amarok::icon( "music" ), 0,
+        TDEAction *gotoCurrent = new TDEAction( i18n("Go To Current Track Folder"), Amarok::icon( "music" ), 0,
                                             TQT_TQOBJECT(this), TQT_SLOT( gotoCurrentFolder() ), actionCollection );
         gotoCurrent->plug( toolbar );
 
@@ -270,7 +270,7 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
 
 FileBrowser::~FileBrowser()
 {
-    KConfig* const c = Amarok::config( "Filebrowser" );
+    TDEConfig* const c = Amarok::config( "Filebrowser" );
 
     m_dir->writeConfig( c ); //uses currently set group
 
@@ -406,11 +406,11 @@ FileBrowser::urlChanged( const KURL &u )
 inline void
 FileBrowser::slotViewChanged( KFileView *view )
 {
-    if( view->widget()->inherits( "KListView" ) )
+    if( view->widget()->inherits( "TDEListView" ) )
     {
         using namespace Amarok::ColorScheme;
 
-        static_cast<KListView*>(view->widget())->setAlternateBackground( AltBase );
+        static_cast<TDEListView*>(view->widget())->setAlternateBackground( AltBase );
     }
 }
 
@@ -424,17 +424,17 @@ inline void
 FileBrowser::prepareContextMenu()
 {
     const KFileItemList &items = *m_dir->selectedItems();
-    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( SavePlaylist,
+    static_cast<TDEActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( SavePlaylist,
         items.count() > 1 || ( items.count() == 1 && items.getFirst()->isDir() ) );
-    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( QueueTrack,
+    static_cast<TDEActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( QueueTrack,
         items.count() == 1  );
-    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( QueueTracks,
+    static_cast<TDEActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( QueueTracks,
         items.count() > 1 );
-    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( MediaDevice,
+    static_cast<TDEActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( MediaDevice,
         MediaBrowser::isAvailable() );
-    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( MoveToCollection, !CollectionDB::instance()->isDirInCollection( url().path() ) );
-    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( CopyToCollection, !CollectionDB::instance()->isDirInCollection( url().path() ) );
-    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( OrganizeFiles, CollectionDB::instance()->isDirInCollection( url().path() ) );
+    static_cast<TDEActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( MoveToCollection, !CollectionDB::instance()->isDirInCollection( url().path() ) );
+    static_cast<TDEActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( CopyToCollection, !CollectionDB::instance()->isDirInCollection( url().path() ) );
+    static_cast<TDEActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( OrganizeFiles, CollectionDB::instance()->isDirInCollection( url().path() ) );
 }
 
 inline void
@@ -527,21 +527,21 @@ FileBrowser::selectAll()
 #include <tqpainter.h>
 #include <tqsimplerichtext.h>
 
-class KURLView : public KListView
+class KURLView : public TDEListView
 {
 public:
-    KURLView( TQWidget *parent ) : KListView( parent )
+    KURLView( TQWidget *parent ) : TDEListView( parent )
     {
         reinterpret_cast<TQWidget*>(header())->hide();
         addColumn( TQString() );
-        setResizeMode( KListView::LastColumn );
+        setResizeMode( TDEListView::LastColumn );
         setDragEnabled( true );
         setSelectionMode( TQListView::Extended );
     }
 
-    class Item : public KListViewItem {
+    class Item : public TDEListViewItem {
     public:
-        Item( const KURL &url, KURLView *parent ) : KListViewItem( parent, url.fileName() ), m_url( url ) {}
+        Item( const KURL &url, KURLView *parent ) : TDEListViewItem( parent, url.fileName() ), m_url( url ) {}
         KURL m_url;
     };
 
@@ -558,7 +558,7 @@ public:
 
     virtual void viewportPaintEvent( TQPaintEvent *e )
     {
-        KListView::viewportPaintEvent( e );
+        TDEListView::viewportPaintEvent( e );
 
         if ( childCount() == 0 ) {
             TQPainter p( viewport() );
@@ -622,7 +622,7 @@ SearchPane::SearchPane( FileBrowser *parent )
         connect( m_listView, TQT_SIGNAL(executed( TQListViewItem* )), TQT_SLOT(activate( TQListViewItem* )) );
     }
 
-    KPushButton *button = new KPushButton( KGuiItem( i18n("&Show Search Panel"), "find" ), this );
+    KPushButton *button = new KPushButton( KGuiItem( i18n("&Show Search Panel"), "edit-find" ), this );
     button->setToggleButton( true );
     connect( button, TQT_SIGNAL(toggled( bool )), TQT_SLOT(toggle( bool )) );
 
