@@ -27,8 +27,6 @@ class TQHttpResponseHeader;
 
 namespace Daap
 {
-    typedef TQMap<TQString, TQVariant>    Map;
-
     typedef TQPtrList< MetaBundle >     TrackList;
     typedef TQMap< TQString, TrackList > AlbumList;
     typedef TQMap< TQString, AlbumList > SongList;
@@ -91,8 +89,8 @@ namespace Daap
             * @param raw stream of DAAP reply
             * @param containerLength length of the container (or entire result) being analyzed
             */
-            static Map parse( TQDataStream &raw, uint containerLength, bool first = false );
-            static void addElement( Map &parentMap, char* tag, TQVariant element ); //! supporter function for parse
+            static TQStringVariantMap parse( TQDataStream &raw, uint containerLength, bool first = false );
+            static void addElement( TQStringVariantMap &parentMap, char* tag, TQVariant element ); //! supporter function for parse
             static TQ_UINT32 getTagAndLength( TQDataStream &raw, char tag[5] );
 
             static TQMap<TQString, Code> s_codes;
