@@ -944,9 +944,9 @@ GenericMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int
         menu.insertItem( SmallIconSet( Amarok::icon( "fastforward" ) ), i18n( "&Queue Tracks" ), QUEUE );
         menu.insertSeparator();
         menu.insertItem( SmallIconSet( Amarok::icon( "collection" ) ), i18n( "&Copy Files to Collection..." ), DOWNLOAD );
-        menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdrom" ) ), i18n( "Burn to CD as Data" ), BURN_DATACD );
+        menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdrom-unmounted" ) ), i18n( "Burn to CD as Data" ), BURN_DATACD );
         menu.setItemEnabled( BURN_DATACD, K3bExporter::isAvailable() );
-        menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdaudio" ) ), i18n( "Burn to CD as Audio" ), BURN_AUDIOCD );
+        menu.insertItem( SmallIconSet( Amarok::icon( "media-optical-cdaudio-unmounted" ) ), i18n( "Burn to CD as Audio" ), BURN_AUDIOCD );
         menu.setItemEnabled( BURN_AUDIOCD, K3bExporter::isAvailable() );
         menu.insertSeparator();
         menu.insertItem( SmallIconSet( Amarok::icon( "folder" ) ), i18n( "Add Directory" ), DIRECTORY );
