@@ -1,7 +1,7 @@
 /***************************************************************************
  * copyright            : (C) 2005-2006 Seb Ruiz <me@sebruiz.net>          *
  *                                                                         *
- * With some code helpers from KIO_IFP                                     *
+ * With some code helpers from TDEIO_IFP                                     *
  *                        (c) 2004 Thomas Loeber <ifp@loeber1.de>          *
  ***************************************************************************/
 
@@ -33,11 +33,11 @@ AMAROK_EXPORT_PLUGIN( IfpMediaDevice )
 #include "statusbar/statusbar.h"
 #include "transferdialog.h"
 
-#include <kapplication.h>
-#include <kconfig.h>           //download saveLocation
+#include <tdeapplication.h>
+#include <tdeconfig.h>           //download saveLocation
 #include <kiconloader.h>       //smallIcon
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kurlrequester.h>     //downloadSelectedItems()
 #include <kurlrequesterdlg.h>  //downloadSelectedItems()
 
@@ -46,7 +46,7 @@ AMAROK_EXPORT_PLUGIN( IfpMediaDevice )
 #include <tqregexp.h>
 
 namespace Amarok {
-    extern KConfig *config( const TQString& );
+    extern TDEConfig *config( const TQString& );
     extern TQString cleanPath( const TQString&, bool );
 }
 
@@ -451,7 +451,7 @@ IfpMediaDevice::downloadTrack( const TQCString& src, const TQCString& dest )
 void
 IfpMediaDevice::downloadSelectedItems()
 {
-//     KConfig *config = Amarok::config( "MediaDevice" );
+//     TDEConfig *config = Amarok::config( "MediaDevice" );
 //     TQString save = config->readEntry( "DownloadLocation", TQString() );  //restore the save directory
     TQString save = TQString();
 
@@ -604,7 +604,7 @@ IfpMediaDevice::addTrackToList( int type, TQString name, int /*size*/ )
 /// Capacity, in kB
 
 bool
-IfpMediaDevice::getCapacity( KIO::filesize_t *total, KIO::filesize_t *available )
+IfpMediaDevice::getCapacity( TDEIO::filesize_t *total, TDEIO::filesize_t *available )
 {
     if( !m_connected ) return false;
 
@@ -649,7 +649,7 @@ IfpMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int )
     MediaItem *item = static_cast<MediaItem *>(qitem);
     if ( item )
     {
-        KPopupMenu menu( m_view );
+        TDEPopupMenu menu( m_view );
         menu.insertItem( SmallIconSet( Amarok::icon( "collection" ) ), i18n( "Download" ), DOWNLOAD );
         menu.insertSeparator();
         menu.insertItem( SmallIconSet( Amarok::icon( "folder" ) ), i18n("Add Directory" ), DIRECTORY );
@@ -683,7 +683,7 @@ IfpMediaDevice::rmbPressed( TQListViewItem* qitem, const TQPoint& point, int )
 
     if( isConnected() )
     {
-        KPopupMenu menu( m_view );
+        TDEPopupMenu menu( m_view );
         menu.insertItem( SmallIconSet( Amarok::icon( "folder" ) ), i18n("Add Directory" ), DIRECTORY );
         int id =  menu.exec( point );
         switch( id )
