@@ -1,5 +1,5 @@
 /***************************************************************************
-                       kmultitabbar.cpp -  description
+                       tdemultitabbar.cpp -  description
                            -------------------
    begin                :  2001
    copyright            : (C) 2001,2002,2003 by Joseph Wenninger <jowenn@kde.org>
@@ -39,18 +39,18 @@
 #include <tqstyle.h>
 #include <tqtimer.h>
 
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 #include <kiconeffect.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kstringhandler.h>
 
 #define NEARBYINT(i) ((int(float(i) + 0.5)))
 
-namespace Amarok { extern KConfig *config( const TQString& ); }
+namespace Amarok { extern TDEConfig *config( const TQString& ); }
 
 class MultiTabBarTabPrivate
 {
@@ -172,7 +172,7 @@ void MultiTabBarInternal::contentsMousePressEvent( TQMouseEvent *ev )
 void MultiTabBarInternal::showTabSelectionMenu(TQPoint pos)
 {
 
-    KPopupMenu popup;
+    TDEPopupMenu popup;
     popup.insertTitle(  i18n("Browsers") , /*id*/ -1, /*index*/ 1 );
     popup.setCheckable( true );
     for( uint i = 0; i < m_tabs.count(); i++ ) {
@@ -419,7 +419,7 @@ int MultiTabBarInternal::appendTab( const TQPixmap &pic , int id, const TQString
     tab->showActiveTabText( m_showActiveTabTexts );
     tab->setVisible( Amarok::config( "BrowserBar" )->readBoolEntry( identifier, true ) );
 
-    if ( m_style == MultiTabBar::KONTQSBC ) {
+    if ( m_style == MultiTabBar::KONQSBC ) {
         if ( m_expandedTabSize < tab->neededSize() ) {
             m_expandedTabSize = tab->neededSize();
             for ( uint i = 0;i < m_tabs.count();i++ )
@@ -801,7 +801,7 @@ void MultiTabBarTab::setState( bool b )
 void MultiTabBarTab::updateState()
 {
 
-    if ( m_style != MultiTabBar::KONTQSBC ) {
+    if ( m_style != MultiTabBar::KONQSBC ) {
         if ( ( m_style == MultiTabBar::KDEV3 ) || ( m_style == MultiTabBar::KDEV3ICON ) || ( m_style == MultiTabBar::AMAROK ) || ( isOn() ) ) {
             TQPushButton::setText( m_text );
         } else {
@@ -858,7 +858,7 @@ void MultiTabBarTab::drawButtonLabel( TQPainter *p )
 void MultiTabBarTab::drawButton( TQPainter *paint )
 {
     if ( m_style == MultiTabBar::AMAROK ) drawButtonAmarok( paint );
-    else if ( m_style != MultiTabBar::KONTQSBC ) drawButtonStyled( paint );
+    else if ( m_style != MultiTabBar::KONQSBC ) drawButtonStyled( paint );
     else drawButtonClassic( paint );
 }
 
@@ -1063,7 +1063,7 @@ void MultiTabBarTab::drawButtonAmarok( TQPainter *paint )
 
         // Apply icon effect when widget disabled. Should really be cached, but *shrug*.
         if( !isEnabled() )
-            icon = kapp->iconLoader()->iconEffect()->apply( icon, KIcon::Small, KIcon::DisabledState );
+            icon = kapp->iconLoader()->iconEffect()->apply( icon, TDEIcon::Small, TDEIcon::DisabledState );
 
         if( m_position == MultiTabBar::Left || m_position == MultiTabBar::Right ) {
             TQPixmap pixmap( height(), width() );
@@ -1161,7 +1161,7 @@ MultiTabBar::MultiTabBar( MultiTabBarMode bm, TQWidget *parent, const char *name
     setPosition( ( bm == MultiTabBar::Vertical ) ? MultiTabBar::Right : MultiTabBar::Bottom );
     setStyle( VSNET );
     //	setStyle(KDEV3);
-    //setStyle(KONTQSBC);
+    //setStyle(KONQSBC);
     m_l->insertWidget( 0, m_internal );
     m_l->insertWidget( 0, m_btnTabSep = new TQFrame( this ) );
     m_btnTabSep->setFixedHeight( 4 );
@@ -1177,7 +1177,7 @@ MultiTabBar::~MultiTabBar()
 
 /*int MultiTabBar::insertButton(TQPixmap pic,int id ,const TQString&)
 {
-(new KToolbarButton(pic,id,m_internal))->show();
+(new TDEToolbarButton(pic,id,m_internal))->show();
 return 0;
 }*/
 
