@@ -3,16 +3,16 @@
 
 #include "mydirlister.h"
 
-#include <kaction.h>
-#include <kdiroperator.h>
-#include <kpopupmenu.h>
+#include <tdeaction.h>
+#include <tdediroperator.h>
+#include <tdepopupmenu.h>
 
 class Medium;
 
 class MyDirOperator : public KDirOperator {
 
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         MyDirOperator( const KURL &url, TQWidget *parent, Medium *medium = 0 );
@@ -22,7 +22,7 @@ class MyDirOperator : public KDirOperator {
         virtual void activatedMenu (const KFileItem *, const TQPoint &pos) {
             updateSelectionDependentActions();
             reenableDeleteKey();
-            static_cast<KActionMenu*>(actionCollection()->action("popupMenu"))->popupMenu()->popup( pos );
+            static_cast<TDEActionMenu*>(actionCollection()->action("popupMenu"))->popupMenu()->popup( pos );
         }
         void myHome();
         void myCdUp();
