@@ -251,7 +251,7 @@ void PlayerWidget::setScroll( const TQStringList &list )
     }
 
     //FIXME empty TQString would crash due to NULL Pixmaps
-    if( text.isEmpty() ) text = i18n( "Please report this message to trinity-devel@lists.pearsoncomputing.net, thanks!" );
+    if( text.isEmpty() ) text = i18n( "Please report this message to devels@trinitydesktop.org, thanks!" );
 
     TQFont font( m_pScrollFrame->font() );
     TQFontMetrics fm( font );
