@@ -4,6 +4,8 @@
 #ifndef AMAROK_PLUGINCONFIG_H
 #define AMAROK_PLUGINCONFIG_H
 
+#include "amarok_export.h"
+
 #include <tqobject.h>
 
 class TQWidget;
@@ -14,10 +16,10 @@ namespace Amarok
      * Class to allow user configuration of your plugin; you provide a GUI widget via view()
      */
 
-    class PluginConfig : public TQObject
+    class LIBAMAROK_EXPORT PluginConfig : public TQObject
     {
         Q_OBJECT
-  
+
 
         signals:
             /** Emit whenever some view setting is changed by the user */
