@@ -35,9 +35,9 @@
 #include <tqtextcodec.h>
 
 #include <dcopref.h>
-#include <kapplication.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 // class ScanController
@@ -83,7 +83,7 @@ ScanController::ScanController( CollectionDB* parent, bool incremental, const TQ
     *m_scanner << "amarokcollectionscanner";
     *m_scanner << "--nocrashhandler"; // We want to be able to catch SIGSEGV
 
-    // KProcess must be started from the GUI thread, so we're invoking the scanner
+    // TDEProcess must be started from the GUI thread, so we're invoking the scanner
     // here in the ctor:
     if( incremental )
     {
